@@ -1,5 +1,6 @@
 from pytest import importorskip
 
+from miutil.fdio import fspath
 from miutil.imio import imread
 
 np = importorskip("numpy")
@@ -9,21 +10,21 @@ def test_imread(tmp_path):
     x = np.random.randint(10, size=(9, 9))
     fname = tmp_path / "test_imread.npy"
     np.save(fname, x)
-    assert (imread(str(fname)) == x).all()
+    assert (imread(fname) == x).all()
 
     fname = tmp_path / "test_imread.npz"
     np.savez(fname, x)
-    assert (imread(str(fname)) == x).all()
+    assert (imread(fname) == x).all()
 
     np.savez(fname, x, x)
-    assert (imread(str(fname))["arr_0"] == x).all()
+    assert (imread(fname)["arr_0"] == x).all()
 
 
 def test_nii(tmp_path):
     nii = importorskip("miutil.imio.nii")
 
     x = np.arange(2 * 2 * 3).reshape(2, 2, 3)
-    fname = str(tmp_path / "test_nii.nii")
+    fname = tmp_path / "test_nii.nii"
     nii.array2nii(x, np.eye(4), fname, flip=(1, 1, 1))
     nii.nii_gzip(fname)
-    assert (imread(fname + ".gz") == x).all()
+    assert (imread(fspath(fname) + ".gz") == x).all()
